Himalaya
========

Welcome to ``Himalaya``'s documentation website.

Documentation
-------------
.. toctree::
   :maxdepth: 2

   getting_started
   models
   troubleshooting
   api

Examples
--------
.. toctree::
   :includehidden:
   :maxdepth: 2
   
    
   _auto_examples/index
